// ***************************************************************
// This file was created using the CreateProject.sh script
// for project CCXSecAnalysis.
// CreateProject.sh is part of Bayesian Analysis Toolkit (BAT).
// BAT can be downloaded from http://www.mppmu.mpg.de/bat
// ***************************************************************

#include <BAT/BCLog.h>
#include <BAT/BCAux.h>
#include <BAT/BCSummaryTool.h>
#include <BAT/BCDataSet.h>
#include <TGraphErrors.h> 
#include <TH2D.h>
#include <TCanvas.h> 

#include "CCXSec.h"

int main()
{

   // set nicer style for drawing than the ROOT default
   BCAux::SetStyle();

   // open log file
   BCLog::OpenLog("log.txt");
   BCLog::SetLogLevel(BCLog::detail);

   // create new CCXSec object
   CCXSec * m = new CCXSec();

   BCLog::OutSummary("Test model created");

   // create a new summary tool object
   BCSummaryTool * summary = new BCSummaryTool(m);

   // read data set from file 
   BCDataSet * mydataset = new BCDataSet();
   mydataset->ReadDataFromFile("data.txt", 3);
   m->SetDataSet(mydataset); 

   // define histogram for data axes 
   TH2D * myhistaxes = new TH2D("myhistaxes", ";Polarization;#sigma_{CC} [pb]", 1, -1., 1., 1, 0.0, 80.); 
   myhistaxes->SetStats(kFALSE); 
   
   // copy data into graph
   TGraphErrors * mygraphdata = new TGraphErrors(mydataset->GetNDataPoints());
   mygraphdata->SetMarkerStyle(20);
   for (int i = 0; i < int(mydataset->GetNDataPoints()); ++i)
     {
       double P = mydataset->GetDataPoint(i)->GetValue(0); 
       double sig = mydataset->GetDataPoint(i)->GetValue(1); 
       double errsig = mydataset->GetDataPoint(i)->GetValue(2); 
       
       mygraphdata->SetPoint(i, P, sig);
       mygraphdata->SetPointError(i, 0.0, errsig);
     } 
   
   // print data 
   TCanvas * mycanvas = new TCanvas("mycanvas"); 
   mycanvas->cd();
   myhistaxes->Draw(); 
   mygraphdata->Draw("SAMEPE"); 
   mycanvas->Print("data.eps"); 
   
   // perform your analysis here
   
   // normalize the posterior, i.e. integrate posterior
   // over the full parameter space
//   m->Normalize();

   // run MCMC and marginalize posterior wrt. all parameters
   // and all combinations of two parameters
//   m->MarginalizeAll();

   // run mode finding; by default using Minuit
//   m->FindMode();

   // if MCMC was run before (MarginalizeAll()) it is
   // possible to use the mode found by MCMC as
   // starting point of Minuit minimization
//   m->FindMode( m->GetBestFitParameters() );

   // draw all marginalized distributions into a PostScript file
//   m->PrintAllMarginalized("CCXSec_plots.ps");

   // print all summary plots
//   summary->PrintParameterPlot("CCXSec_parameters.eps");
//   summary->PrintCorrelationPlot("CCXSec_correlation.eps");
//   summary->PrintKnowledgeUpdatePlots("CCXSec_update.ps");

   // calculate p-value
//   m->CalculatePValue( m->GetBestFitParameters() );

   // print results of the analysis into a text file
//   m->PrintResults("CCXSec_results.txt");

   delete m;
   delete summary;

   BCLog::OutSummary("Test program ran successfully");
   BCLog::OutSummary("Exiting");

   // close log file
   BCLog::CloseLog();

   return 0;

}

